import os
def usage():
  # export the environment variables
  print("export KALM_NETBOX_URL=\"\"")
  print("export KALM_NETBOX_TOKEN=\"\"")
  print("export KALM_NETBOX_SSL=\"\"")


def  get_env():
  myenv = {}
  try:
    myenv['KALM_NETBOX_URL'] = os.getenv("KALM_NETBOX_URL")
    myenv['KALM_NETBOX_TOKEN'] = os.getenv("KALM_NETBOX_TOKEN")
    myenv['KALM_NETBOX_SSL'] = os.getenv("KALM_NETBOX_SSL", "false")
  except KeyError as key_error:
    print(key_error)
    usage()
    raise SystemExit("Unable to get environment variables.")
  if myenv['KALM_NETBOX_URL'] == None:
    usage()
    raise SystemExit("Unable to get environment variables.")
  if myenv['KALM_NETBOX_TOKEN'] == None:
    usage()
    raise SystemExit("Unable to get environment variables.")
  
  if myenv['KALM_NETBOX_SSL'] == "false" or myenv['KALM_NETBOX_SSL'] == "False" or myenv['KALM_NETBOX_SSL'] == "FALSE" or myenv['KALM_NETBOX_SSL'] == "no" or myenv['KALM_NETBOX_SSL'] == "NO" or myenv['KALM_NETBOX_SSL'] == "No":
    myenv['KALM_NETBOX_SSL'] = False
  else:
    myenv['KALM_NETBOX_SSL'] = True
  if myenv['KALM_NETBOX_URL'][-1] == "/":
    myenv['KALM_NETBOX_URL'] = myenv['KALM_NETBOX_URL'][:-1]

  return myenv



import requests
import json
import os
import base64
import xml.etree.ElementTree as ET
import platform
import pprint
import yaml
from ..common import prettyllog

def get_clusters(env):
    clusters = {}
    url = env['KALM_NETBOX_URL'] + "/api/virtualization/clusters/"
    headers = {'Authorization': 'Token ' + env['KALM_NETBOX_TOKEN']}
    r = requests.get(url, headers=headers, verify=env['KALM_NETBOX_SSL'])
    if r.status_code == 200:
        data = r.json()
        for cluster in data['results']:
            clusters[cluster['name']] = cluster['id']
    else:
        prettyllog("netbox", "get", "clusters", "error", r.status_code , "unable to get clusters", severity="ERROR")
    return clusters

def get_cluster_id(cluster_name, env):
    clusters = get_clusters(env)
    try: 
        return clusters[cluster_name]
    except:
        return False
    
def create_cluster(cluster_name, env):
    url = env['KALM_NETBOX_URL'] + "/api/virtualization/clusters/"
    headers = {'Authorization': 'Token ' + env['KALM_NETBOX_TOKEN']}
    data = {
        "name": cluster_name,
        "type": 1,
        "group": 1,
        "site": 1,
        "comments": "Created by KALM"
    }
    r = requests.post(url, headers=headers, data=data, verify=env['KALM_NETBOX_SSL'])
    if r.status_code == 201:
        data = r.json()
        return data['id']
    else:
        prettyllog("netbox", "create", "cluster", cluster_name, r.status_code , "unable to create cluster", severity="ERROR")
        return False

def update_cluster(cluster_name, cluster_type, group, site, env):
    url = env['KALM_NETBOX_URL'] + "/api/virtualization/clusters/" + str(cluster_id) + "/"
    headers = {'Authorization': 'Token ' + env['KALM_NETBOX_TOKEN']}
    data = {
        "name": cluster_name,
        "type": 1,
        "group": 1,
        "site": 1,
        "comments": "Updated by KALM"
    }
    r = requests.put(url, headers=headers, data=data, verify=env['KALM_NETBOX_SSL'])
    if r.status_code == 200:
        data = r.json()
        return data['id']
    else:
        prettyllog("netbox", "update", "cluster", cluster_name, r.status_code , "unable to update cluster", severity="ERROR")
        return False